class Counter:

    """ A class to represent a counter that wraps around from a high value back
    to its low value."""

    def __init__(self, low, high):
        """ Creates a Counter object with the given low and high values """
        self.low = low
        self.high = high
        self.value = low

    def __str__(self):
        "Returns a string representation of this Counter object."
        result = "Value: " + str(self.value)
        result += " Low: " + str(self.low)
        result += " High: " + str(self.high)
        return result

    def increment(self, amount=1):
        """ Increment the counter by the given amount, wrapping around to low
        again, if necessary. Returns number of times had to wrap around. """
        
        range_of_nums = self.high-self.low+1
        
        # the number of times this will wrap around
        num_wraps = amount/range_of_nums
        
        # the "real" amount to increment by
        real_inc_amount = amount%range_of_nums
        
        self.value += real_inc_amount
        if self.value > self.high:
            self.value = self.low + (self.value - self.high - 1)

        return num_wraps
        
    def decrement(self, amount=1):
        """ Decrement the counter by the given amount (a positive number),
        wrapping around to high again, if necessary. Returns number of times had
        to wrap around. """
        range_of_nums = self.high-self.low+1
        num_wraps = amount/range_of_nums
        real_dec_amount = amount % range_of_nums
        
        self.value -= real_dec_amount
        if self.value < self.low:
            self.value = self.high - (self.low - self.value + 1)

        return num_wraps

    def setValue(self, value):
        """ Sets the counter's value, only if low <= value <= high.  Otherwise,
        prints an error message."""
        if value >= self.low and value <= self.high:
            self.value = value
        else:
            print "ERROR: value must be within range", self.low, "-", \
                  self.high

    def getValue(self):
        return self.value

    def getLow(self):
        return self.low

    def getHigh(self):
        return self.high

def testCounter():
    c = Counter(5,10)
    print c
    c.increment()
    print c
    c.increment(3)
    print "Current value:", c.getValue()
    c.increment(4)
    print c
    print "Increment by 20 --> wraps", c.increment(20), "times"
    print c
    c.decrement()
    print c
    print "Decrement by 20 --> wraps", c.decrement(20), "times"
    print c

#testCounter()

