"""
 How hard do you have to hit a baseball to hit it over 
 the Green Monster at Fenway Park? Run this program to test 
 your guesses.

 Author: Andrew Danner, 09.20.2007
"""

from graphics import *
from time import sleep
from math import *

MPH2FPS = 5280.0/3600. #conversion from mph to fps
DEG2RAD = pi/180.0 #conversion from degrees to radians
GRAVITY=32  #gravity in ft/s^2
NUM_STEPS = 70

def main():

  mph = input("Enter the speed off the bat in mph: ")
  angle = input("Enter an angle in degrees: ")

  win=GraphWin("Fenway", 700, 600)
  win.setBackground("lightblue")
  win.setCoords(0, 0, 350, 300)

  greenMonster = Rectangle(Point(304,0), Point(310, 37))
  greenMonster.setFill("darkgreen")
  greenMonster.setOutline("darkgreen")
  greenMonster.draw(win)

  fallTime = timeToFall(angle, mph)
  vx = changeInXVelocity(angle, mph)
  vy = changeInYVelocity(angle, mph)

  for t in xrange(NUM_STEPS):
    tnow = t/fallTime
    #assume initial ball height of 4 feet
    y = 4+vy*tnow - 0.5*GRAVITY*tnow*tnow
    x = vx*tnow
    ball = Circle(Point(x,y),3)
    ball.setFill("white")
    ball.draw(win)
    sleep(fallTime/NUM_STEPS)
  
  win.getMouse()
  win.close()


# Compute the time for the ball to fall, plus a few seconds.
# Input: the angle (in degrees) and the speed the ball was hit at (in
# miles per hour)
# Returns the time in seconds for the ball to fall
def timeToFall(angle, mph):
  theta = angle * DEG2RAD
  v = mph * MPH2FPS
  vy = v*sin(theta)
  vx = v*cos(theta)
  tf = 2*vy/GRAVITY  #time it takes to fall back down, plus a few secs
  return tf

# Compute the change in vertical velocity
def changeInYVelocity(angle, mph):
  theta = angle * DEG2RAD
  v = mph * MPH2FPS
  return v*sin(theta)

# Compute the change in horizontal velocity
def changeInXVelocity(angle, mph):
  theta = angle * DEG2RAD
  v = mph * MPH2FPS
  return v*cos(theta)



main()
