<!--Template adapted from www.oswd.org.  "Sinorca" template originally designed by haran-->
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en-AU">
  <head>
    <meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
    
	<title>CS 111: Fundamentals of Programming I</title>
        <link rel="stylesheet" type="text/css" href="course.css" />

</head>

  <body>
 <? include("header.php"); ?>
 <? include("sidebar.php"); ?>

    <!-- ##### Main Copy ##### -->

    <div id="main-copy">
   
   <h1>Programming Style</h1>
   
   <p>Programming is not a dry mechanical process but an art form.
   Well-written code has an aesthetic appeal while poor form can make other
   programmers and instructors cringe. While having good comments or good
   variable names will not affect the correctness of your program, they make
   it much easier to read your program. It is important that others can
   understand your code so that they can modify your code if they have to. A
   <i>significant</i> component of your lab grade will be determined by your
   programming style.

   <p>Briefly, good programming practices usually include the
   following principles:

   <ul>
   
    <li>A comment at the top of the program that includes
      <ul>
        <li>Program authors
        <li>Date or Dates
        <li>A brief description of what the program does
      </ul> 
    <li>Concise comments that summarize major sections of your code
    <li>Meaningful variable and function names
    <li>Well-organized code
    <li>White space or comments to improve legibility
    <li>Avoidance of large blocks of copy-pasted code
  </ul>

   <p>This page elaborates on these principles and serves as a guide to help
   you better understand what we are looking for when we look at your
   programs. As the semester progresses there will be steeper penalties for
   styling mistakes. Get into the habit of writing programs with good style
   from the beginning. After writing your lab be sure to look over your code
   and your style.
   
   
   <h2>Commenting</h2>
   
   <p>Comments are extremely important. Take some care to write accurate yet
   concise comments.

   <ul>
      
      <li>Be specific with your comments. Your comments should describe the
      <i>intent</i> of the code. What are you trying to accomplish with this
      piece of code?
      
      <li>Do not make your comments (or code) too wide. Any line of comment
      or code that is over 80 characters should be split up over several
      lines. If many lines in your program do not print nicely, your program
      will be difficult to read.
    
      <li>Do not overcomment! Overcommenting can make the program hard to
      read just as much as under-commenting. Do <b>not</b> comment every
      line. If your instructions are simple and clear, most people will
      understand them without your comments. If you think you need
      commenting, try commenting chunks of code under the same comment.
    
      <li>Delete any extraneous code. You would not hand in an English paper
      with crossed out lines. Similarly, you should not hand in a lab with
      commented out code. Remove all code that your program no longer uses.
  </ul>
  
  <p>You should write comments for
  
  <ul>
  
    <li><b>Programs and modules:</b> At the top of each
    script/program/module, you should write your name, the date, and a brief
    description of what the script does. If you do more than the assignment
    requested, you should describe these "extra" features in the program
    under the class description. Sometimes it's hard to tell a bug from a
    feature.
   
  
    <li><b>Variables and constants</b>: In general, variables and constants
    should all have comments as to what the variable is used for.
    Frequently, several closely related variables or constants can be
    grouped together under the same comment.
    
    <li><b>Functions and Methods</b>: Above each function or method heading,
    describe what the function or method <i>does</i>. <i>Do not describe the
    implementation details.</i> You should also describe what each parameter
    means and what the <code>return</code> result means. If the code is
    simple, you do not need to comment within the body. If the body is
    complicated, add some comments to blocks of code to explain the
    implementation.
   
    <li><b>Classes</b>: Describe what your class represents, briefly, at a
    high-level.
   
  </ul> 
   
  <p>Note that we will not have all of these code "components" until later in
  the semester.
   
  <h2>Blank Lines</h2>

<p>Blank lines are used to delineate different areas of the code. There should
always be a blank line between definitions of functions, methods, and
classes. It is advisable to break up long method bodies and long
declarations into logical pieces, usually headed by a descriptive comment of
what the following block of code does.

  <h2>Naming Literals</h2>

<p>Do not use magic numbers in your method bodies. A magic number is a
numeric constant embedded in code, without a constant definition. Any number
except -1, 0, 1, and 2 should probably have a name that gives the number
meaning. For example, rather than writing

<br><code>toLower = chr(ord(capletter)-26)</code> 

<br>associate a constant variable with the number:

        <br><code>NUM_ALPHA_LETTERS = 26</code> 

<br>and use that variable in place of the number:

<br><code>toLower = chr(ord(capletter)-NUM_ALPHA_LETTERS)</code> 
  
  <h2>Names</h2>

  <p>You should always choose names that suggest the meanings of the things
  being named. If the purpose of a function is to remove all the blanks from
  a string, then a good name for that method is removeBlanks. If there is a
  variable of type int that is used to refer to the total number of message
  that have been sent, then a good name would be messageCount.

  <p>In general, follow the following rules of thumb:

  <ul>

    <li>Names that have nothing to do with the program are very bad names!
    Example: <code> harry = "lemonade"</code>
    
    <li>Names that are not specific or descriptive enough are generally bad
    names.
    
    <li>Try not to name objects sequentially. You should only do this when
    the objects are related in some way that is not otherwise expressible.
    Ex., <code>data1</code> and <code>data2</code> are not as
    good as <code>firstName</code> and <code>lastName</code>.
    if the data represent a user's first name and last name.

  </ul>    

  <p>By convention, constants are all capital letters; classes begin with
  uppercase letters; variable, function, and method names begin with
  lowercase, while uppercase is used to start new words in multi-word names.
  We also use an underscore ("_") to separate multi-word names.

<p><b>Examples:</b>

<p>
<TABLE BORDER="1" width=75%>
<TR>
	<TH COLSPAN="2" bgcolor=#E0E0E0 align=center>Variables</TH>
</TR>
<TR>
	<TH WIDTH="50%">Good</TH>
	<TH>Bad</TH>
</TR>
<TR>
	<TD VALIGN="top">
distance<br>
velocity<br>
acceleration<br>
numLetters<br>
num_letters<br>
	<TD VALIGN="top">
d<br>
ve<br>
A<br>
n<br>
num</br>
</TR>
<TR>
	<TH COLSPAN="2" bgcolor=#E0E0E0 align=center>Functions</TH>
</TR>
<TR>
	<TH>Good</TH>
	<TH>Bad</TH>
</TR>
<TR>
	<TD VALIGN="top">

drawPicture<br>
squareRoot<br>
computePrice<br>
	<TD VALIGN="top">
computeImage (less clear for this case)<br>
sqrt<br>
total<br>
</TR>
</TABLE>

 

<p>
   <hr>

   <cite>Portions adapted from style guides for Williams College's CS134 and
   Swarthmore College's CS21</cite>

</body>
</html>
